<?php
/**
 * Pre-Parse Signature Plugin
 * Copyright © 2009 Ryan Gordon - NCAABBS Skunkworks Division
 *
 * Website: http://ncaabbs.com
 * License: GNU/GPL
 *
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$plugins->add_hook('usercp_do_editsig_process', 'preparsersig_usercp');
$plugins->add_hook('datahandler_user_insert', 'preparsersig_datahandler_user_insert');
$plugins->add_hook('datahandler_user_update', 'preparsersig_datahandler_user_update');
$plugins->add_hook('showthread_start', 'preparsersig_showthread');
$plugins->add_hook('newreply_do_newreply_start', 'preparsersig_newreply');
$plugins->add_hook('newreply_start', 'preparsersig_newreply');
$plugins->add_hook('postbit', 'preparsersig_functions_post');

function preparsersig_info()
{
	return array(
		"name"			=> "Pre-Parse Signature",
		"description"	=> "A plugin which aims to speed up MyBB's showthread by caching parsed versions of signatures",
		"website"		=> "http://thetikitiki.com",
		"author"		=> "Ryan Gordon",
		"authorsite"	=> "http://thetikitiki.com",
		"version"		=> "1.0.2",
		"compatibility" => "14*",
		"guid"			=> "",
	);
}

function preparsersig_install()
{
	global $db, $parser, $mybb;
	
	if(!$db->field_exists('parsedsig', "users"))
	{
		$db->query("ALTER TABLE ".TABLE_PREFIX."users ADD parsedsig text NOT NULL AFTER signature;");
	}
	
	if(!isset($parser))
	{
		require_once MYBB_ROOT.'inc/class_parser.php';
		$parser = new postParser;
	}
	
	$sig_parser = array(
		"allow_html" => $mybb->settings['sightml'],
		"allow_mycode" => $mybb->settings['sigmycode'],
		"allow_smilies" => $mybb->settings['sigsmilies'],
		"allow_imgcode" => $mybb->settings['sigimgcode'],
	);
	
	$query = $db->simple_select("users", "uid,username,signature");
	while($user = $db->fetch_array($query))
	{
		if($user['signature'] == "")
		{
			continue;
		}
		
		$sig_parser['me_username'] = $user['username'];
		
		$db->update_query("users", array('parsedsig' => $db->escape_string($parser->parse_message($user['signature'], $sig_parser))), "uid='{$user['uid']}'", 1);
	}
}

function preparsersig_is_installed()
{
	global $db;
	
	if($db->field_exists("parsedsig", "users"))
	{
		return true;
	}
	
	return false;
}


function preparsersig_activate()
{
}


function preparsersig_deactivate()
{
}

function preparsersig_uninstall()
{
	global $db;
	
	if($db->field_exists('parsedsig', "users"))
	{
		$db->query("ALTER TABLE ".TABLE_PREFIX."users DROP parsedsig;");
	}
}

function preparsersig_newreply()
{
	global $mybb;

	if(($mybb->input['ajax'] == 1 && $mybb->input['action'] == "do_newreply") 
	|| ($mybb->input['previewpost'] && $mybb->input['action'] == "newreply"))
	{
		$mybb->user['realshowsigs'] = $mybb->user['showsigs'];
		$mybb->user['showsigs'] = 0;
	}
}

function preparsersig_showthread()
{
	global $mybb;

	$mybb->user['realshowsigs'] = $mybb->user['showsigs'];
	$mybb->user['showsigs'] = 0;
}

function preparsersig_functions_post(&$post)
{
	global $mybb, $templates;
	
	if($mybb->user['realshowsigs'] != 0)
	{
		if($post['parsedsig'] == "" && $post['signature'] != "")
		{
			global $parser, $db;
			
			if(!isset($parser))
			{
				require_once MYBB_ROOT.'inc/class_parser.php';
				$parser = new postParser;
			}
			
			$sig_parser = array(
				"allow_html" => $mybb->settings['sightml'],
				"allow_mycode" => $mybb->settings['sigmycode'],
				"allow_smilies" => $mybb->settings['sigsmilies'],
				"allow_imgcode" => $mybb->settings['sigimgcode'],
				"me_username" => $post['username'],
			);
			
			$post['parsedsig'] = $parser->parse_message($post['signature'], $sig_parser);
			
			$db->update_query("users", array('parsedsig' => $db->escape_string($post['parsedsig'])), "uid='{$post['uid']}'", 1);
		}
		
		$post['signature'] = $post['parsedsig'];
	
		eval("\$post['signature'] = \"".$templates->get("postbit_signature")."\";");
	}
	else
	{
		$post['signature'] = "";
	}
}

function preparsersig_datahandler_user_update(&$user)
{
	global $parser, $mybb, $db;
	
	if($user->user_update_data['signature'] == "")
	{
		$user->user_update_data['parsedsig'] = "";
		return;
	}
	
	if(!isset($parser))
	{
		require_once MYBB_ROOT.'inc/class_parser.php';
		$parser = new postParser;
	}
	
	$sig_parser = array(
		"allow_html" => $mybb->settings['sightml'],
		"allow_mycode" => $mybb->settings['sigmycode'],
		"allow_smilies" => $mybb->settings['sigsmilies'],
		"allow_imgcode" => $mybb->settings['sigimgcode'],
		"me_username" => $user->user_update_data['username'],
	);
			
	$user->user_update_data['parsedsig'] = $db->escape_string($parser->parse_message($user->data['signature'], $sig_parser));
}

function preparsersig_datahandler_user_insert(&$user)
{
	global $parser, $mybb, $db;
	
	if($user->user_insert_data['signature'] == "")
	{
		$user->user_insert_data['parsedsig'] = "";
		return;
	}
	
	if(!isset($parser))
	{
		require_once MYBB_ROOT.'inc/class_parser.php';
		$parser = new postParser;
	}
	
	$sig_parser = array(
		"allow_html" => $mybb->settings['sightml'],
		"allow_mycode" => $mybb->settings['sigmycode'],
		"allow_smilies" => $mybb->settings['sigsmilies'],
		"allow_imgcode" => $mybb->settings['sigimgcode'],
		"me_username" => $user->user_update_data['username'],
	);
			
	$user->user_insert_data['parsedsig'] = $db->escape_string($parser->parse_message($user->data['signature'], $sig_parser));
}

function preparsersig_usercp()
{
	global $new_signature, $parser, $mybb, $db;
	
	if($mybb->input['signature'] == "")
	{
		$new_signature['parsedsig'] = "";
		return;
	}
	
	if(!isset($parser))
	{
		require_once MYBB_ROOT.'inc/class_parser.php';
		$parser = new postParser;
	}
	
	$sig_parser = array(
		"allow_html" => $mybb->settings['sightml'],
		"allow_mycode" => $mybb->settings['sigmycode'],
		"allow_smilies" => $mybb->settings['sigsmilies'],
		"allow_imgcode" => $mybb->settings['sigimgcode'],
		"me_username" => $mybb->user['username'],
	);
			
	$new_signature['parsedsig'] = $db->escape_string($parser->parse_message($mybb->input['signature'], $sig_parser));
}
?>